@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_events._jsii
@@ -21,9 +21,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-events-rule-step-function",
-    "1.61.0",
+    "1.63.0",
     __name__[0:-6],
-    "aws-events-rule-step-function@1.61.0.jsii.tgz",
+    "aws-events-rule-step-function@1.63.0.jsii.tgz",
 )
 
 __all__ = [
